<?php
/**
 * The template used for displaying sections content
 *
 * @package shrk
 */
?>

<?php global $shrk_sections_printed; ?>
<?php $page_sections[] = $section_id = $post->ID; ?>
<?php $shrk_sections_printed[] = $section_id; ?>

<section id="<?php echo esc_attr($post->post_name); ?>" class="section container-wrapper <?php echo esc_attr(shrk_get_section_class()); ?>" <?php echo shrk_get_section_data_attr(); ?>>
	<?php echo shrk_get_section_backgrounds( $section_id ); ?>
	<div class="container" <?php echo shrk_get_section_cont_attr(); ?>>
		<div class="row">
			<div class="main-content-inner col-12 col-lg-12">
				<?php shrk_get_the_section_title(); ?>
				<?php the_content(); ?>
			</div><!-- close .*-inner -->
		</div><!-- close .row -->
	</div><!-- close .container -->
	<?php echo shrk_get_section_edit_link( $section_id ); ?>
	<?php do_action( 'shrk_action_section_after', $section_id ); ?>
</section><!-- close section .container-wrapper -->
